<?php header('Content-type: text/html; charset=utf-8'); ?>
<?php

/******************************************************************
// load viewer library
*******************************************************************/
//$libraryPath = 'cmsAdmin/lib/viewer_functions.php';
//$dirsToCheck = ['','../','../../','../../../','../../../../']; // add if needed: '/home/...'
//foreach ($dirsToCheck as $dir) { if (@include_once("$dir$libraryPath")) { break; }}
//if (!function_exists('getRecords')) { die("Couldn't load viewer library, check filepath in sourcecode."); }

include_once 'calendar_functions.php';

// Retrieve and validate GET parameters for the view and navigation
$params = getCalendarParams();
$view  = $params['view'];
$year  = $params['year'];
$month = $params['month'];
$week  = $params['week'];
$day   = $params['day'];


// Determine if we're in example mode or production mode (can be based on a constant or environment variable)
$mode = 'example'; // or 'production'


// Check the execution mode
if ($mode === 'production') {

	$FORMAT_START = 'Y-m-d 00:00:00';  // Format for the start of a period (midnight)
	$FORMAT_END   = 'Y-m-d 23:59:59';  // Format for the end of a period (11:59 PM)

	switch ($view) {
		case 'month':
			// Create a date for the first day of the month
			$date = sprintf("%04d-%02d-01", $year, $month);
			
			// For the month, take the previous and next month
			$debut = date($FORMAT_START, strtotime("$date -1 month"));               // Previous month
			$fin   = date($FORMAT_END, strtotime("$date +1 month +1 month -1 day")); // End of the next month
			
			// Look for events that overlap with this period
			$query = "start_date <= '$fin' AND end_date >= '$debut'";
			break;

		case 'week':
			// Create a date for the first day of the week
			$debut_semaine = date($FORMAT_START, strtotime("{$year}-W{$week}"));
			
			// Take the previous and next week
			$debut = date($FORMAT_START, strtotime("$debut_semaine -1 week"));      // Previous week
			$fin   = date($FORMAT_END, strtotime("$debut_semaine +2 week -1 day")); // End of the next week
			
			// Look for events that overlap with this period
			$query = "start_date <= '$fin' AND end_date >= '$debut'";
			break;

		case 'day':
			// Create the start and end dates for the specified day
			$debut = sprintf("%04d-%02d-%02d 00:00:00", $year, $month, $day);
			$fin   = sprintf("%04d-%02d-%02d 23:59:59", $year, $month, $day);
			
			// Look for events happening on that day
			$query = "(start_date BETWEEN '$debut' AND '$fin') 
					  OR (end_date BETWEEN '$debut' AND '$fin')
					  OR (start_date <= '$debut' AND end_date >= '$fin')";
			break;
			
		case 'year':
			// Create the start and end dates for the year
			$debut = sprintf("%04d-01-01 00:00:00", $year);
			$fin   = sprintf("%04d-12-31 23:59:59", $year);
			
			// Look for events happening this year
			$query = "(start_date BETWEEN '$debut' AND '$fin') 
					  OR (end_date BETWEEN '$debut' AND '$fin')
					  OR (start_date <= '$debut' AND end_date >= '$fin')";
			break;
			
		default:
			// If the view is not valid, return an empty string
			$query = "";
			break;
	}

    // Load records from the 'events' table
    list($events) = getRecords(array(
        'tableName'   => 'events',
        'where'       => $query,
        'loadUploads' => true,
        'allowSearch' => false,
        'debugSql'    => false,
    ));

} else {

	// Example mode: use a static array with mock events
	$events = [
		[
			'title' => 'Annual Conference',
			'start_date' => '2024-10-21 09:00:00',
			'end_date' => '2024-10-21 17:00:00',
			'permalink' => 'annual-conference',
			'description' => 'Annual conference on technological innovations.',
			'location' => 'Main Auditorium',
			'color' => 'red'
		],
		[
			'title' => 'Digital Marketing Seminar',
			'start_date' => '2024-10-22 10:00:00',
			'end_date' => '2024-10-22 15:00:00',
			'permalink' => 'digital-marketing-seminar',
			'description' => 'Seminar on the latest trends in digital marketing.',
			'location' => 'Meeting Room B',
			'color' => '#FFC200'
		],
		[
			'title' => 'Team Meeting',
			'start_date' => '2024-10-25 14:00:00',
			'end_date' => '2024-10-26 12:00:00',
			'permalink' => 'team-meeting',
			'description' => 'Weekly team meeting to discuss progress.',
			'location' => 'Conference Room C',
			'color' => '#90CAF9'
		],
		[
			'title' => 'PHP Workshop...',
			'start_date' => '2024-11-02 07:30:00',
			'end_date' => '2024-11-02 17:00:00',
			'permalink' => 'php-workshop',
			'description' => 'A hands-on workshop on PHP development.',
			'location' => 'Training Room D',
			'color' => '#FFBC66'
		],
		[
			'title' => 'Product Launch',
			'start_date' => '2024-11-30 10:00:00',
			'end_date' => '2024-11-30 16:00:00',
			'permalink' => 'product-launch',
			'description' => 'Launch event for our new product.',
			'location' => 'Main Hall',
			'color' => '#FFABAB'
		],
		[
			'title' => 'Holiday Party W49',
			'start_date' => '2024-12-01 18:00:00',
			'end_date' => '2024-12-01 23:00:00',
			'permalink' => 'holiday-party',
			'description' => 'Annual holiday party for all employees.',
			'location' => 'Rooftop Lounge',
			'color' => '#D1C4E9'
			// This event appears in week 49
		],
		[
			'title' => 'Year-End Review W49',
			'start_date' => '2024-12-02 14:00:00',
			'end_date' => '2024-12-02 17:00:00',
			'permalink' => 'year-end-review',
			'description' => 'Review of the year\'s achievements and goals.',
			'location' => 'Conference Room A',
			'color' => '#FFBC66'
			// This event appears in week 49
		]
	];
}


/******************************************************************
// Set HTTP headers for cache control
*******************************************************************/
header('Cache-Control: no-cache, no-store, must-revalidate'); // No caching allowed
header('Expires: 0'); // Set expiration to 0
header_remove('Pragma'); // Remove pragma header

?><!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Calendar <?php echo date('Y'); ?></title>

<style>
	.container {
		width: 90%;
		margin: 20px auto;
	}

	.view-switcher {
		display: flex;
		gap: 10px;
		justify-content: left;
		align-items: center;
		margin: 20px auto;
		text-align: center;
	}

	.view-switcher a {
		text-decoration: none;
	}

	.view-switcher a.active {
		font-weight: bold;
	}

	.calendar-navigation {
		display: flex;
		gap: 10px;
		justify-content: center;
		align-items: center;
		margin: 20px auto;
		text-align: center;
	}

	.calendar-month {
		width: 100%;
		border-collapse: collapse;
	}

	.calendar-month th, .calendar-month td {
		width: 14.28%;
		border: 1px solid #ccc;
		padding: 10px;
		text-align: center;
		vertical-align: top;
	}

	.calendar-month .day {
		position: relative;
		min-height: 50px;
	}

	.calendar-month .day-number {
		position: absolute;
		top: 0;
		right: 0;
		padding: 5px;
		font-weight: bold;
		color: inherit;
	}

	.calendar-month .today {
		background-color: #ffeb3b;
	}

	.calendar-month .prev-month, .calendar-month .next-month {
		color: #999;
		background-color: #f5f5f5;
	}

	.calendar-month .event {
		margin-top: 5px;
		background-color: #90caf9;
		padding: 3px;
		border-radius: 3px;
	}

	.calendar-week {
		width: 100%;
		border-collapse: collapse;
		table-layout: fixed; /* Ensures fixed distribution of columns */
	}

	.calendar-week th, .calendar-week td {
		width: 40px;
		border: 1px solid #ccc;
		padding: 10px;
		text-align: center;
		word-wrap: break-word;
	}

	.calendar-week .hour {
		width: 40px; /* Fixed width for the "hour" column */
		background-color: #f9f9f9;
		text-align: center;
		padding-right: 10px;
		font-weight: bold;
	}

	/* Apply equal width to other columns */
	.calendar-week th:not(:first-child), .calendar-week td:not(:first-child) {
		width: calc((100% - 40px) / 7); /* Equal width for other columns */
	}

	.calendar-day {
		width: 100%;
		border-collapse: collapse;
	}

	.calendar-day th, .calendar-day td {
		border: 1px solid #ccc;
		padding: 10px;
		text-align: center;
		vertical-align: top;
	}

	.calendar-day .hour {
		width: 40px;
		background-color: #f9f9f9;
		text-align: center;
		padding: 10px;
		font-weight: bold;
	}

	.calendar-day .day-event {
		width: 100%;
		padding-left: 10px;
		text-align: left;
	}

	.calendar-day .day-event a {
		color: inherit;
	}

	.event {
		background-color: #90caf9;
		padding: 5px;
		margin: 3px 0;
		border-radius: 4px;
	}

	.event-time {
		font-size: 0.8em;
		color: inherit;
	}

	/* Basic styles for the event link */
	.calendar-month .event a,
	.calendar-week .event a {
		position: relative;
		text-decoration: none;
		color: inherit;
	}

	/* Styles for the tooltip */
	.calendar-month .tooltiptext,
	.calendar-week .tooltiptext {
		visibility: hidden;
		width: 200px;
		background-color: rgba(0, 0, 0, 0.8);
		color: #fff;
		text-align: center;
		border-radius: 5px;
		padding: 10px;
		position: absolute;
		z-index: 1;
		bottom: 100%;
		left: 50%;
		margin-left: -100px;
		opacity: 0;
		transition: opacity 0.3s;
	}

	/* Displays the tooltip when hovering over the link */
	.calendar-month .event a:hover .tooltiptext,
	.calendar-week .event a:hover .tooltiptext {
		visibility: visible;
		opacity: 1;
	}

	.calendar-year {
		display: flex;
		flex-wrap: wrap;
		gap: 20px;
	}

	.calendar-year-month {
		flex: 1 0 calc(33.33% - 20px); /* Three columns with spacing */
		width: 14.28%;
		border: 1px solid #ccc;
		padding: 10px;
		border-radius: 5px;
		box-sizing: border-box;
	}

	/* Media query to switch to two columns */
	@media (max-width: 1480px) {
		.calendar-year-month {
			flex: 1 0 calc(50% - 20px); /* Two columns */
		}
	}

	/* Media query to switch to one column */
	@media (max-width: 868px) {
		.calendar-year-month {
			flex: 1 0 100%; /* One column */
		}
	}

	.calendar-year .day {
		display: flex;
		flex-direction: column; /* Column to stack elements */
		align-items: flex-end; /* Align to the right */
		min-height: 50px; /* Minimum height to leave space for content */
		padding: 5px; /* Space inside */
		position: relative; /* Necessary for positioned elements */
	}

	.calendar-year .day-number {
		padding: 5px;
		font-weight: bold;
		color: inherit;
	}

	.event-points-container {
		display: flex;
		flex-wrap: wrap; /* Allows to wrap automatically */
		justify-content: center; /* Centers the points */
		gap: 4px; /* Space between points */
		margin-top: 30px; /* Space between the number and the points */
	}

	.event-point {
		width: 10px;
		height: 10px;
		border-radius: 50%;
		background-color: #6993B5; /* Example color for the points */
		display: inline-block; /* Important for points to be in line */
		cursor: pointer;
	}

	/* Positioning the tooltip on hover over the points */
	.event-point .tooltiptext {
		visibility: hidden;
		width: 120px;
		background-color: rgba(0, 0, 0, 0.8);
		color: #fff;
		text-align: center;
		border-radius: 5px;
		padding: 5px;
		position: absolute;
		z-index: 1;
		bottom: 150%; /* Adjust if necessary */
		left: 50%;
		margin-left: -60px;
		opacity: 0;
		transition: opacity 0.3s;
	}

	/* Shows the tooltip on hover */
	.event-point:hover .tooltiptext {
		visibility: visible;
		opacity: 1;
	}
	
	.dark-text {
	  color: #000;
	}

	.light-text {
	  color: #fff;
	}
</style>

</head>
<body>

<div class="container">

<?php 
	// Display the view switcher to toggle between 'month', 'week', and 'day' views
	renderViewSwitcher($month, $year, $week, $view, $lang, $translations);

	// Select and display the calendar view based on the user's choice (month, week, day, year)
	if ($view == 'month') {

		// Display navigation for the month (buttons to go to the previous or next month)
		renderMonthNavigation($month, $year, $lang, $translations);

		// Display the monthly view with the month's events
		renderMonthCalendar($month, $year, $events, $weekStart, $lang, $translations);

	} elseif ($view == 'week') {

		// Display navigation for the week (buttons to go to the previous or next week)
		renderWeekNavigation($year, $week, $lang, $translations);

		// Display the weekly view with the week's events
		renderWeekView($month, $year, $week, $events, $weekStart, $lang, $translations, $workingStartTime, $workingEndTime);

	} elseif ($view == 'day') {

		// Display navigation for the day (buttons to go to the previous or next day)
		renderDayNavigation($month, $year, $day, $lang, $translations);

		// Display the daily view with events, including the hours of the day
		renderDayViewWithHours($month, $year, $day, $events, $lang, $translations, $workingStartTime, $workingEndTime);
		
	} elseif ($view == 'year') {

		// Display navigation for the year
		renderYearNavigation($year, $lang, $translations);

		// Display the annual calendar
		renderYearCalendar($year, $events, $weekStart, $lang, $translations);
	}
?>

</div>


<script>
  // Function to calculate the brightness of a hexadecimal color
  function getBrightness(hexColor) {
    hexColor = hexColor.replace('#', '');
    const r = parseInt(hexColor.substring(0, 2), 16);
    const g = parseInt(hexColor.substring(2, 4), 16);
    const b = parseInt(hexColor.substring(4, 6), 16);
    return (r * 0.299 + g * 0.587 + b * 0.114);
  }

  // Function to convert RGB to hexadecimal
  function rgbToHex(rgb) {
    const result = rgb.match(/\d+/g).map(num => parseInt(num, 10).toString(16).padStart(2, '0'));
    return `#${result.join('')}`;
  }

  // Applies the contrast class to each element with the `.event` class
  function applyTextColor() {
    const events = document.querySelectorAll('.event');
    events.forEach(element => {
      const backgroundColor = getComputedStyle(element).backgroundColor;
      const hexColor = rgbToHex(backgroundColor);
      const brightness = getBrightness(hexColor);

      if (brightness > 128) {
        element.classList.add('dark-text');
      } else {
        element.classList.add('light-text');
      }
    });
  }

  applyTextColor(); // Execute the function for all elements with the `.event` class
</script>


</body>
</html>